Documentation
¶
Index ¶
- type ProgressBar
- type Prompt
- func (p *Prompt) ChooseFile(files []string) (string, error)
- func (p *Prompt) ConfirmFileOverwrite(path string) (bool, error)
- func (p *Prompt) ConfirmFileRemoval(path, message string) (bool, constants.DeleteOption, error)
- func (p *Prompt) GetDecryptionPassword() (string, error)
- func (p *Prompt) GetEncryptionPassword() (string, error)
- func (p *Prompt) GetProcessingMode() (constants.ProcessorMode, error)
- func (p *Prompt) ShowFileInfo(files []constants.FileInfo)
- func (p *Prompt) ShowInfo(message string)
- func (p *Prompt) ShowProcessingInfo(mode constants.ProcessorMode, file string)
- func (p *Prompt) ShowSuccess(message string)
- func (p *Prompt) ShowWarning(message string)
- type Terminal
- func (t *Terminal) Cleanup()
- func (t *Terminal) Clear()
- func (t *Terminal) MoveTopLeft()
- func (t *Terminal) PrintBanner()
- func (t *Terminal) PrintError(message string)
- func (t *Terminal) PrintInfo(message string)
- func (t *Terminal) PrintSeparator()
- func (t *Terminal) PrintSuccess(message string)
- func (t *Terminal) PrintWarning(message string)
- func (t *Terminal) SetTitle(title string)
- func (t *Terminal) ShowCursor()
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ProgressBar ¶
type ProgressBar struct {
// contains filtered or unexported fields
}
ProgressBar provides progress tracking functionality
func NewProgressBar ¶
func NewProgressBar(totalSize int64, description string) *ProgressBar
NewProgressBar creates a new progress bar with the given total size and description
func (*ProgressBar) Add ¶
func (p *ProgressBar) Add(size int64) error
Add increments the progress bar by the given amount
type Prompt ¶
type Prompt struct{}
Prompt provides methods for interactive command-line prompts
func (*Prompt) ChooseFile ¶
ChooseFile prompts the user to select a file from the provided list
func (*Prompt) ConfirmFileOverwrite ¶
ConfirmFileOverwrite prompts the user to confirm overwriting an existing file
func (*Prompt) ConfirmFileRemoval ¶
ConfirmFileRemoval prompts for confirmation and deletion method for file removal
func (*Prompt) GetDecryptionPassword ¶
GetDecryptionPassword prompts for a password for decryption
func (*Prompt) GetEncryptionPassword ¶
GetEncryptionPassword prompts for and confirms a password for encryption
func (*Prompt) GetProcessingMode ¶
func (p *Prompt) GetProcessingMode() (constants.ProcessorMode, error)
GetProcessingMode prompts the user to select a processing operation
func (*Prompt) ShowFileInfo ¶
ShowFileInfo displays information about files to be processed
func (*Prompt) ShowProcessingInfo ¶
func (p *Prompt) ShowProcessingInfo(mode constants.ProcessorMode, file string)
ShowProcessingInfo displays information about the processing pipeline
func (*Prompt) ShowSuccess ¶
ShowSuccess displays a success message to the user
func (*Prompt) ShowWarning ¶
ShowWarning displays a warning message to the user
type Terminal ¶
type Terminal struct{}
Terminal provides terminal control functionality
func (*Terminal) Cleanup ¶
func (t *Terminal) Cleanup()
Cleanup performs terminal cleanup operations
func (*Terminal) MoveTopLeft ¶
func (t *Terminal) MoveTopLeft()
MoveTopLeft moves the cursor to the top-left corner
func (*Terminal) PrintBanner ¶
func (t *Terminal) PrintBanner()
PrintBanner prints the application banner
func (*Terminal) PrintError ¶
PrintError prints an error message with formatting
func (*Terminal) PrintSeparator ¶
func (t *Terminal) PrintSeparator()
PrintSeparator prints a visual separator
func (*Terminal) PrintSuccess ¶
PrintSuccess prints a success message with formatting
func (*Terminal) PrintWarning ¶
PrintWarning prints a warning message with formatting